@@ -7,10 +7,8 @@ from media_platform.service.media_platform_service import MediaPlatformService
 
 
 class SanitationService(MediaPlatformService):
-    def __init__(self, domain: str, authenticated_http_client: AuthenticatedHTTPClient,
-                 app_authenticator: AppAuthenticator):
+    def __init__(self, domain: str, authenticated_http_client: AuthenticatedHTTPClient):
         super().__init__(domain, authenticated_http_client)
-        self.app_authenticator = app_authenticator
 
     def sanitation_request(self) -> SanitationRequest:
         return SanitationRequest(self._authenticated_http_client, self._base_url)
